@@ -18,7 +18,7 @@ use subs qw(DD_FLT_RADIX DD_LDBL_MAX DD_LDBL_MIN DD_LDBL_DIG DD_LDBL_MANT_DIG
  DD_LDBL_MIN_EXP DD_LDBL_MAX_EXP DD_LDBL_MIN_10_EXP DD_LDBL_MAX_10_EXP
  DD_LDBL_EPSILON DD_LDBL_DECIMAL_DIG DD_LDBL_HAS_SUBNORM DD_LDBL_TRUE_MIN
  NV2H H2NV D2H H2D DD2HEX std_float_H LD2H H2LD
- get_sign get_exp get_mant_H float_H H_float inter_zero are_inf are_nan
+ get_sign get_exp get_doubles get_mant_H float_H H_float inter_zero are_inf are_nan
  float_H2B B2float_H standardise_bin_mant hex_float float_hex float_B B_float
  valid_hex valid_bin valid_unpack express NV2binary
  float_is_infinite float_is_nan float_is_finite float_is_zero float_is_nzfinite
@@ -30,7 +30,7 @@ use subs qw(DD_FLT_RADIX DD_LDBL_MAX DD_LDBL_MIN DD_LDBL_DIG DD_LDBL_MANT_DIG
  DD_LDBL_MIN_EXP DD_LDBL_MAX_EXP DD_LDBL_MIN_10_EXP DD_LDBL_MAX_10_EXP
  DD_LDBL_EPSILON DD_LDBL_DECIMAL_DIG DD_LDBL_HAS_SUBNORM DD_LDBL_TRUE_MIN
  NV2H H2NV D2H H2D DD2HEX std_float_H LD2H H2LD
- get_sign get_exp get_mant_H float_H H_float inter_zero are_inf are_nan
+ get_sign get_exp get_doubles get_mant_H float_H H_float inter_zero are_inf are_nan
  float_H2B B2float_H standardise_bin_mant float_hex hex_float float_B B_float
  valid_hex valid_bin valid_unpack express NV2binary
  float_is_infinite float_is_nan float_is_finite float_is_zero float_is_nzfinite
@@ -50,7 +50,7 @@ $Data::Float::DoubleDouble::neg_eps = -(2 ** -1074);
 $Data::Float::DoubleDouble::max_fin =  H2NV('7fefffffffffffff7c8fffffffffffff');
 $Data::Float::DoubleDouble::min_fin = $Data::Float::DoubleDouble::max_fin * -1;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 #$VERSION = eval $VERSION;
 DynaLoader::bootstrap Data::Float::DoubleDouble $VERSION;
 
@@ -161,6 +161,15 @@ sub get_exp {
 
 }
 
+##############################
+##############################
+# Return the 2 doubles encapsulated in the given doubledouble.
+
+sub get_doubles {
+  my $ld_hex = NV2H($_[0]);
+  return (H2D(substr($ld_hex, 0, 16)), H2D(substr($ld_hex, 16, 16)));
+}
+
 ##############################
 ##############################
 # Return the (hex) mantissas of the 2 doubles.
@@ -1257,6 +1266,12 @@ Data::Float::DoubleDouble -  human-readable representation of the "double-double
 
   #############################################
 
+  ($double1, $double2) = get_doubles($nv);
+
+   Returns the two doubles contained in $nv.
+
+  #############################################
+
   ($mantissa1, $mantissa2) = get_mant_H(NV2H($nv));
 
    Returns an array of the two 52-bit mantissa components of
